@@ -308,7 +308,10 @@ class Evaluator_SMIRNOFF(Target):
         bool
             Returns True if the parameter is a cosmetic one.
         """
-        import simtk.unit as simtk_unit
+        try:
+            import openmm.unit as simtk_unit
+        except ImportError:
+            import simtk.unit as simtk_unit
 
         parameter_handler = self.FF.openff_forcefield.get_parameter_handler(
             gradient_key.tag
