@@ -253,7 +253,7 @@ class Liquid(Target):
 
     def read_data(self):
         # Read the 'data.csv' file. The file should contain guidelines.
-        with open(os.path.join(self.tgtdir,'data.csv'),'rU') as f: R0 = list(csv.reader(f))
+        with open(os.path.join(self.tgtdir,'data.csv'),'r') as f: R0 = list(csv.reader(f))
         # All comments are erased.
         R1 = [[sub('#.*$','',word) for word in line] for line in R0 if len(line[0]) > 0 and line[0][0] != "#"]
         # All empty lines are deleted and words are converted to lowercase.
@@ -727,7 +727,6 @@ class Liquid(Target):
         @return property_results
 
         """
-
         unpack = lp_load('forcebalance.p')
         mvals1 = unpack[1]
         if len(mvals) > 0 and (np.max(np.abs(mvals1 - mvals)) > 1e-3):
